@@ -109,33 +109,11 @@ G_DEFINE_TYPE (GsdMouseManager, gsd_mouse_manager, G_TYPE_OBJECT)
 static gpointer manager_object = NULL;
 
 
-static GObject *
-gsd_mouse_manager_constructor (GType                  type,
-                              guint                  n_construct_properties,
-                              GObjectConstructParam *construct_properties)
-{
-        GsdMouseManager      *mouse_manager;
-
-        mouse_manager = GSD_MOUSE_MANAGER (G_OBJECT_CLASS (gsd_mouse_manager_parent_class)->constructor (type,
-                                                                                                      n_construct_properties,
-                                                                                                      construct_properties));
-
-        return G_OBJECT (mouse_manager);
-}
-
-static void
-gsd_mouse_manager_dispose (GObject *object)
-{
-        G_OBJECT_CLASS (gsd_mouse_manager_parent_class)->dispose (object);
-}
-
 static void
 gsd_mouse_manager_class_init (GsdMouseManagerClass *klass)
 {
         GObjectClass   *object_class = G_OBJECT_CLASS (klass);
 
-        object_class->constructor = gsd_mouse_manager_constructor;
-        object_class->dispose = gsd_mouse_manager_dispose;
         object_class->finalize = gsd_mouse_manager_finalize;
 
         g_type_class_add_private (klass, sizeof (GsdMouseManagerPrivate));
