@@ -78,10 +78,15 @@ class PowerPluginTest(gsdtestcase.GSDTestCase):
         self.settings_screensaver = Gio.Settings('org.gnome.desktop.screensaver')
         self.settings_screensaver['lock-enabled'] = False
 
+        # Ensure we set up the external monitor state
+        self.set_has_external_monitor(False)
+
         self.settings_gsd_power = Gio.Settings('org.gnome.settings-daemon.plugins.power')
 
         # start power plugin
         self.settings_gsd_power['active'] = False
+        # As hibernate is not available, suspend by default on critical
+        self.settings_gsd_power['critical-battery-action'] = 'suspend'
         Gio.Settings.sync()
         self.plugin_log_write = open(os.path.join(self.workdir, 'plugin_power.log'), 'wb')
         # avoid painfully long delays of actions for tests
@@ -761,7 +766,7 @@ class PowerPluginTest(gsdtestcase.GSDTestCase):
         # Drop inhibitor
         self.obj_session_mgr.Uninhibit(dbus.UInt32(inhibit_id))
 
-    def test_unindle_on_ac_plug(self):
+    def disabled_test_unindle_on_ac_plug(self):
         idle_delay = round(gsdpowerconstants.MINIMUM_IDLE_DIM_DELAY / gsdpowerconstants.IDLE_DELAY_TO_IDLE_DIM_MULTIPLIER)
         self.settings_session['idle-delay'] = idle_delay
 
