@@ -1070,26 +1070,11 @@ gnome_xsettings_manager_stop (GnomeXSettingsManager *manager)
         }
 }
 
-static GObject *
-gnome_xsettings_manager_constructor (GType                  type,
-                                     guint                  n_construct_properties,
-                                     GObjectConstructParam *construct_properties)
-{
-        GnomeXSettingsManager      *xsettings_manager;
-
-        xsettings_manager = GNOME_XSETTINGS_MANAGER (G_OBJECT_CLASS (gnome_xsettings_manager_parent_class)->constructor (type,
-                                                                                                                  n_construct_properties,
-                                                                                                                  construct_properties));
-
-        return G_OBJECT (xsettings_manager);
-}
-
 static void
 gnome_xsettings_manager_class_init (GnomeXSettingsManagerClass *klass)
 {
         GObjectClass *object_class = G_OBJECT_CLASS (klass);
 
-        object_class->constructor = gnome_xsettings_manager_constructor;
         object_class->finalize = gnome_xsettings_manager_finalize;
 
         g_type_class_add_private (klass, sizeof (GnomeXSettingsManagerPrivate));
